{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.AlignmentObject where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | An intangible item that describes an alignment between a learning resource and a node in an educational framework.
--
--   [@id@] AlignmentObject
--
--   [@label@] Alignment Object
--
--   [@comment@] An intangible item that describes an alignment between a learning resource and a node in an educational framework.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/AlignmentObject>
data AlignmentObject = AlignmentObject { alignmentType :: AlignmentType
                                       , educationalFramework :: EducationalFramework
                                       , targetDescription :: TargetDescription
                                       , targetName :: TargetName
                                       , targetUrl :: TargetUrl
                                       , additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData AlignmentObject where
  _label         = const "Alignment Object"
  _comment_plain = const "An intangible item that describes an alignment between a learning resource and a node in an educational framework."
  _comment       = const "An intangible item that describes an alignment between a learning resource and a node in an educational framework."
  _url           = const "http://schema.org/AlignmentObject"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]