{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Bone where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AnatomicalStructure

-- | Rigid connective tissue that comprises up the skeletal structure of the human body.
--
--   [@id@] Bone
--
--   [@label@] Bone
--
--   [@comment@] Rigid connective tissue that comprises up the skeletal structure of the human body.
--
--   [@ancestors@] @'Thing','MedicalEntity','AnatomicalStructure'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'AnatomicalStructure'@
--
--   [@url@] <http://schema.org/Bone>
data Bone = Bone { associatedPathophysiology :: AssociatedPathophysiology
                 , bodyLocation :: BodyLocation
                 , connectedTo :: ConnectedTo
                 , diagram :: Diagram
                 , function :: Function
                 , partOfSystem :: PartOfSystem
                 , relatedCondition :: RelatedCondition
                 , relatedTherapy :: RelatedTherapy
                 , subStructure :: SubStructure
                 , code :: Code
                 , guideline :: Guideline
                 , medicineSystem :: MedicineSystem
                 , recognizingAuthority :: RecognizingAuthority
                 , relevantSpecialty :: RelevantSpecialty
                 , study :: Study
                 , additionalType :: AdditionalType
                 , alternateName :: AlternateName
                 , description :: Description
                 , image :: Image
                 , mainEntityOfPage :: MainEntityOfPage
                 , name :: Name
                 , potentialAction :: PotentialAction
                 , sameAs :: SameAs
                 , url :: Url
                 }
            deriving (Show, Read, Eq, Typeable)

instance MetaData Bone where
  _label         = const "Bone"
  _comment_plain = const "Rigid connective tissue that comprises up the skeletal structure of the human body."
  _comment       = const "Rigid connective tissue that comprises up the skeletal structure of the human body."
  _url           = const "http://schema.org/Bone"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AnatomicalStructure.AnatomicalStructure)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AnatomicalStructure.AnatomicalStructure)]