{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.LodgingBusiness where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LodgingBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BedAndBreakfast
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Hostel
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Hotel
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Motel

-- | A lodging business, such as a motel, hotel, or inn.
--
--   [@id@] LodgingBusiness
--
--   [@label@] Lodging Business
--
--   [@comment@] A lodging business, such as a motel, hotel, or inn.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','LodgingBusiness','Thing','Place','LocalBusiness'@
--
--   [@subtypes@] @'BedAndBreakfast','Hostel','Hotel','Motel'@
--
--   [@supertypes@] @'LocalBusiness'@
--
--   [@url@] <http://schema.org/LodgingBusiness>
data LodgingBusiness = LodgingBusiness { branchCode :: BranchCode
                                       , currenciesAccepted :: CurrenciesAccepted
                                       , openingHours :: OpeningHours
                                       , paymentAccepted :: PaymentAccepted
                                       , priceRange :: PriceRange
                                       , address :: Address
                                       , aggregateRating :: AggregateRating
                                       , alumni :: Alumni
                                       , areaServed :: AreaServed
                                       , award :: Award
                                       , brand :: Brand
                                       , contactPoint :: ContactPoint
                                       , department :: Department
                                       , dissolutionDate :: DissolutionDate
                                       , duns :: Duns
                                       , email :: Email
                                       , employee :: Employee
                                       , event :: Event
                                       , faxNumber :: FaxNumber
                                       , founder :: Founder
                                       , foundingDate :: FoundingDate
                                       , foundingLocation :: FoundingLocation
                                       , globalLocationNumber :: GlobalLocationNumber
                                       , hasOfferCatalog :: HasOfferCatalog
                                       , hasPOS :: HasPOS
                                       , isicV4 :: IsicV4
                                       , legalName :: LegalName
                                       , location :: Location
                                       , logo :: Logo
                                       , makesOffer :: MakesOffer
                                       , member :: Member
                                       , memberOf :: MemberOf
                                       , naics :: Naics
                                       , numberOfEmployees :: NumberOfEmployees
                                       , owns :: Owns
                                       , parentOrganization :: ParentOrganization
                                       , review :: Review
                                       , seeks :: Seeks
                                       , subOrganization :: SubOrganization
                                       , taxID :: TaxID
                                       , telephone :: Telephone
                                       , vatID :: VatID
                                       , additionalProperty :: AdditionalProperty
                                       , address :: Address
                                       , aggregateRating :: AggregateRating
                                       , branchCode :: BranchCode
                                       , containedInPlace :: ContainedInPlace
                                       , containsPlace :: ContainsPlace
                                       , event :: Event
                                       , faxNumber :: FaxNumber
                                       , geo :: Geo
                                       , globalLocationNumber :: GlobalLocationNumber
                                       , hasMap :: HasMap
                                       , isicV4 :: IsicV4
                                       , logo :: Logo
                                       , openingHoursSpecification :: OpeningHoursSpecification
                                       , photo :: Photo
                                       , review :: Review
                                       , telephone :: Telephone
                                       , additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData LodgingBusiness where
  _label         = const "Lodging Business"
  _comment_plain = const "A lodging business, such as a motel, hotel, or inn."
  _comment       = const "A lodging business, such as a motel, hotel, or inn."
  _url           = const "http://schema.org/LodgingBusiness"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LodgingBusiness.LodgingBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BedAndBreakfast.BedAndBreakfast)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Hostel.Hostel)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Hotel.Hotel)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Motel.Motel)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)]