{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.MedicalProcedureType where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Enumeration
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEnumeration
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalProcedureType
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalIntangible

-- | An enumeration that describes different types of medical procedures.
--
--   [@id@] MedicalProcedureType
--
--   [@label@] Medical Procedure Type
--
--   [@comment@] An enumeration that describes different types of medical procedures.
--
--   [@ancestors@] @'Thing','Intangible','Enumeration','MedicalEnumeration','MedicalProcedureType','Thing','Intangible','Enumeration','MedicalProcedureType','Thing','MedicalEntity','MedicalIntangible','MedicalEnumeration'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Enumeration','MedicalEnumeration'@
--
--   [@url@] <http://schema.org/MedicalProcedureType>
data MedicalProcedureType = MedicalProcedureType { supersededBy :: SupersededBy
                                                 , code :: Code
                                                 , guideline :: Guideline
                                                 , medicineSystem :: MedicineSystem
                                                 , recognizingAuthority :: RecognizingAuthority
                                                 , relevantSpecialty :: RelevantSpecialty
                                                 , study :: Study
                                                 , additionalType :: AdditionalType
                                                 , alternateName :: AlternateName
                                                 , description :: Description
                                                 , image :: Image
                                                 , mainEntityOfPage :: MainEntityOfPage
                                                 , name :: Name
                                                 , potentialAction :: PotentialAction
                                                 , sameAs :: SameAs
                                                 , url :: Url
                                                 }
                            deriving (Show, Read, Eq, Typeable)

instance MetaData MedicalProcedureType where
  _label         = const "Medical Procedure Type"
  _comment_plain = const "An enumeration that describes different types of medical procedures."
  _comment       = const "An enumeration that describes different types of medical procedures."
  _url           = const "http://schema.org/MedicalProcedureType"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalProcedureType.MedicalProcedureType)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalProcedureType.MedicalProcedureType)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIntangible.MedicalIntangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEnumeration.MedicalEnumeration)]