{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.NGO where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization

-- | Organization: Non-governmental Organization.
--
--   [@id@] NGO
--
--   [@label@] NGO
--
--   [@comment@] Organization: Non-governmental Organization.
--
--   [@ancestors@] @'Thing','Organization'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Organization'@
--
--   [@url@] <http://schema.org/NGO>
data NGO = NGO { address :: Address
               , aggregateRating :: AggregateRating
               , alumni :: Alumni
               , areaServed :: AreaServed
               , award :: Award
               , brand :: Brand
               , contactPoint :: ContactPoint
               , department :: Department
               , dissolutionDate :: DissolutionDate
               , duns :: Duns
               , email :: Email
               , employee :: Employee
               , event :: Event
               , faxNumber :: FaxNumber
               , founder :: Founder
               , foundingDate :: FoundingDate
               , foundingLocation :: FoundingLocation
               , globalLocationNumber :: GlobalLocationNumber
               , hasOfferCatalog :: HasOfferCatalog
               , hasPOS :: HasPOS
               , isicV4 :: IsicV4
               , legalName :: LegalName
               , location :: Location
               , logo :: Logo
               , makesOffer :: MakesOffer
               , member :: Member
               , memberOf :: MemberOf
               , naics :: Naics
               , numberOfEmployees :: NumberOfEmployees
               , owns :: Owns
               , parentOrganization :: ParentOrganization
               , review :: Review
               , seeks :: Seeks
               , subOrganization :: SubOrganization
               , taxID :: TaxID
               , telephone :: Telephone
               , vatID :: VatID
               , additionalType :: AdditionalType
               , alternateName :: AlternateName
               , description :: Description
               , image :: Image
               , mainEntityOfPage :: MainEntityOfPage
               , name :: Name
               , potentialAction :: PotentialAction
               , sameAs :: SameAs
               , url :: Url
               }
           deriving (Show, Read, Eq, Typeable)

instance MetaData NGO where
  _label         = const "NGO"
  _comment_plain = const "Organization: Non-governmental Organization."
  _comment       = const "Organization: Non-governmental Organization."
  _url           = const "http://schema.org/NGO"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)]