{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.OrderItem where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | An order item is a line of an order. It includes the quantity and shipping details of a bought offer.
--
--   [@id@] OrderItem
--
--   [@label@] Order Item
--
--   [@comment@] An order item is a line of an order. It includes the quantity and shipping details of a bought offer.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/OrderItem>
data OrderItem = OrderItem { orderDelivery :: OrderDelivery
                           , orderItemNumber :: OrderItemNumber
                           , orderItemStatus :: OrderItemStatus
                           , orderQuantity :: OrderQuantity
                           , orderedItem :: OrderedItem
                           , additionalType :: AdditionalType
                           , alternateName :: AlternateName
                           , description :: Description
                           , image :: Image
                           , mainEntityOfPage :: MainEntityOfPage
                           , name :: Name
                           , potentialAction :: PotentialAction
                           , sameAs :: SameAs
                           , url :: Url
                           }
                 deriving (Show, Read, Eq, Typeable)

instance MetaData OrderItem where
  _label         = const "Order Item"
  _comment_plain = const "An order item is a line of an order. It includes the quantity and shipping details of a bought offer."
  _comment       = const "An order item is a line of an order. It includes the quantity and shipping details of a bought offer."
  _url           = const "http://schema.org/OrderItem"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]