{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.PerformingGroup where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DanceGroup
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MusicGroup
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TheaterGroup

-- | A performance group, such as a band, an orchestra, or a circus.
--
--   [@id@] PerformingGroup
--
--   [@label@] Performing Group
--
--   [@comment@] A performance group, such as a band, an orchestra, or a circus.
--
--   [@ancestors@] @'Thing','Organization'@
--
--   [@subtypes@] @'DanceGroup','MusicGroup','TheaterGroup'@
--
--   [@supertypes@] @'Organization'@
--
--   [@url@] <http://schema.org/PerformingGroup>
data PerformingGroup = PerformingGroup { address :: Address
                                       , aggregateRating :: AggregateRating
                                       , alumni :: Alumni
                                       , areaServed :: AreaServed
                                       , award :: Award
                                       , brand :: Brand
                                       , contactPoint :: ContactPoint
                                       , department :: Department
                                       , dissolutionDate :: DissolutionDate
                                       , duns :: Duns
                                       , email :: Email
                                       , employee :: Employee
                                       , event :: Event
                                       , faxNumber :: FaxNumber
                                       , founder :: Founder
                                       , foundingDate :: FoundingDate
                                       , foundingLocation :: FoundingLocation
                                       , globalLocationNumber :: GlobalLocationNumber
                                       , hasOfferCatalog :: HasOfferCatalog
                                       , hasPOS :: HasPOS
                                       , isicV4 :: IsicV4
                                       , legalName :: LegalName
                                       , location :: Location
                                       , logo :: Logo
                                       , makesOffer :: MakesOffer
                                       , member :: Member
                                       , memberOf :: MemberOf
                                       , naics :: Naics
                                       , numberOfEmployees :: NumberOfEmployees
                                       , owns :: Owns
                                       , parentOrganization :: ParentOrganization
                                       , review :: Review
                                       , seeks :: Seeks
                                       , subOrganization :: SubOrganization
                                       , taxID :: TaxID
                                       , telephone :: Telephone
                                       , vatID :: VatID
                                       , additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData PerformingGroup where
  _label         = const "Performing Group"
  _comment_plain = const "A performance group, such as a band, an orchestra, or a circus."
  _comment       = const "A performance group, such as a band, an orchestra, or a circus."
  _url           = const "http://schema.org/PerformingGroup"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.DanceGroup.DanceGroup)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MusicGroup.MusicGroup)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TheaterGroup.TheaterGroup)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)]