{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.PsychologicalTreatment where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalTherapy

-- | A process of care relying upon counseling, dialogue, communication, verbalization aimed at improving a mental health condition.
--
--   [@id@] PsychologicalTreatment
--
--   [@label@] Psychological Treatment
--
--   [@comment@] A process of care relying upon counseling, dialogue, communication, verbalization aimed at improving a mental health condition.
--
--   [@ancestors@] @'Thing','MedicalEntity','MedicalTherapy'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalTherapy'@
--
--   [@url@] <http://schema.org/PsychologicalTreatment>
data PsychologicalTreatment = PsychologicalTreatment { adverseOutcome :: AdverseOutcome
                                                     , contraindication :: Contraindication
                                                     , duplicateTherapy :: DuplicateTherapy
                                                     , indication :: Indication
                                                     , seriousAdverseOutcome :: SeriousAdverseOutcome
                                                     , code :: Code
                                                     , guideline :: Guideline
                                                     , medicineSystem :: MedicineSystem
                                                     , recognizingAuthority :: RecognizingAuthority
                                                     , relevantSpecialty :: RelevantSpecialty
                                                     , study :: Study
                                                     , additionalType :: AdditionalType
                                                     , alternateName :: AlternateName
                                                     , description :: Description
                                                     , image :: Image
                                                     , mainEntityOfPage :: MainEntityOfPage
                                                     , name :: Name
                                                     , potentialAction :: PotentialAction
                                                     , sameAs :: SameAs
                                                     , url :: Url
                                                     }
                              deriving (Show, Read, Eq, Typeable)

instance MetaData PsychologicalTreatment where
  _label         = const "Psychological Treatment"
  _comment_plain = const "A process of care relying upon counseling, dialogue, communication, verbalization aimed at improving a mental health condition."
  _comment       = const "A process of care relying upon counseling, dialogue, communication, verbalization aimed at improving a mental health condition."
  _url           = const "http://schema.org/PsychologicalTreatment"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalTherapy.MedicalTherapy)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalTherapy.MedicalTherapy)]